summaryrefslogtreecommitdiffstats
path: root/qt/qextscintillacommand.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qt/qextscintillacommand.cpp')
-rw-r--r--qt/qextscintillacommand.cpp60
1 files changed, 30 insertions, 30 deletions
diff --git a/qt/qextscintillacommand.cpp b/qt/qextscintillacommand.cpp
index 57f9ee1..ab37b92 100644
--- a/qt/qextscintillacommand.cpp
+++ b/qt/qextscintillacommand.cpp
@@ -3,29 +3,29 @@
// Copyright (c) 2006
// Riverbank Computing Limited <info@riverbankcomputing.co.uk>
//
-// This file is part of QScintilla.
+// This file is part of TQScintilla.
//
-// This copy of QScintilla is free software; you can redistribute it and/or
+// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
//
-// QScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
+// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
-// QScintilla; see the file LICENSE. If not, write to the Free Software
+// TQScintilla; see the file LICENSE. If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-#include <qnamespace.h>
-#include <qapplication.h>
+#include <tqnamespace.h>
+#include <tqapplication.h>
-#include "qextscintillacommand.h"
-#include "qextscintilla.h"
-#include "qextscintillabase.h"
+#include "tqextscintillacommand.h"
+#include "tqextscintilla.h"
+#include "tqextscintillabase.h"
static int convert(int key);
@@ -99,23 +99,23 @@ bool QextScintillaCommand::validKey(int key)
}
// Convert a Qt character to the Scintilla equivalent. Return zero if it is
// invalid.
static int convert(int key)
{
// Convert the modifiers.
int sci_mod = 0;
- if (key & Qt::SHIFT)
+ if (key & TQt::SHIFT)
sci_mod |= QextScintillaBase::SCMOD_SHIFT;
- if (key & Qt::CTRL)
+ if (key & TQt::CTRL)
sci_mod |= QextScintillaBase::SCMOD_CTRL;
- if (key & Qt::ALT)
+ if (key & TQt::ALT)
sci_mod |= QextScintillaBase::SCMOD_ALT;
- key &= ~Qt::MODIFIER_MASK;
+ key &= ~TQt::MODIFIER_MASK;
// Convert the key.
int sci_key;
@@ -123,59 +123,59 @@ static int convert(int key)
if (key > 0x7f)
switch (key)
{
- case Qt::Key_Down:
+ case TQt::Key_Down:
sci_key = QextScintillaBase::SCK_DOWN;
break;
- case Qt::Key_Up:
+ case TQt::Key_Up:
sci_key = QextScintillaBase::SCK_UP;
break;
- case Qt::Key_Left:
+ case TQt::Key_Left:
sci_key = QextScintillaBase::SCK_LEFT;
break;
- case Qt::Key_Right:
+ case TQt::Key_Right:
sci_key = QextScintillaBase::SCK_RIGHT;
break;
- case Qt::Key_Home:
+ case TQt::Key_Home:
sci_key = QextScintillaBase::SCK_HOME;
break;
- case Qt::Key_End:
+ case TQt::Key_End:
sci_key = QextScintillaBase::SCK_END;
break;
- case Qt::Key_Prior:
+ case TQt::Key_Prior:
sci_key = QextScintillaBase::SCK_PRIOR;
break;
- case Qt::Key_Next:
+ case TQt::Key_Next:
sci_key = QextScintillaBase::SCK_NEXT;
break;
- case Qt::Key_Delete:
+ case TQt::Key_Delete:
sci_key = QextScintillaBase::SCK_DELETE;
break;
- case Qt::Key_Insert:
+ case TQt::Key_Insert:
sci_key = QextScintillaBase::SCK_INSERT;
break;
- case Qt::Key_Escape:
+ case TQt::Key_Escape:
sci_key = QextScintillaBase::SCK_ESCAPE;
break;
- case Qt::Key_Backspace:
+ case TQt::Key_Backspace:
sci_key = QextScintillaBase::SCK_BACK;
break;
- case Qt::Key_Tab:
+ case TQt::Key_Tab:
sci_key = QextScintillaBase::SCK_TAB;
break;
- case Qt::Key_Return:
+ case TQt::Key_Return:
sci_key = QextScintillaBase::SCK_RETURN;
break;
@@ -193,7 +193,7 @@ static int convert(int key)
// Return the translated user friendly description.
-QString QextScintillaCommand::description() const
+TQString QextScintillaCommand::description() const
{
- return qApp -> translate("QextScintillaCommand",descCmd);
+ return tqApp -> translate("QextScintillaCommand",descCmd);
}
@@ -99,23 +99,23 @@ bool QextScintillaCommand::validKey(int key)
}
-// Convert a Qt character to the Scintilla equivalent. Return zero if it is
+// Convert a TQt character to the Scintilla equivalent. Return zero if it is
// invalid.
static int convert(int key)